@@ -108,17 +108,17 @@ def _get_one_batch_after_timestamp(consumer, latest_timestamp):
         return None, None
 
     batch = s3.Object(metadata["bucket_name"], metadata["file_name"]).get()['Body'].read()
-    return batch, metadata["timestamp"]
+    return batch, metadata["timestamp"], metadata['file_name'], metadata
     
 
 def start_processor(process, consumer): 
     latest_timestamp = _get_latest_processed_timestamp(consumer)
     while True:
         print('latest_timestamp before : ', latest_timestamp)
-        batch, latest_timestamp = _get_one_batch_after_timestamp(consumer, latest_timestamp)
+        batch, latest_timestamp, file_name, metadata = _get_one_batch_after_timestamp(consumer, latest_timestamp)
         print('latest_timestamp after : ', latest_timestamp)
         if batch is None:
             print("batch is None")
             return
-        process(batch)
+        process(batch, latest_timestamp, file_name, metadata)
         _update_latest_processed_timestamp(consumer, latest_timestamp)
